import{d as s,a6 as m,z as n,W as e,c as l,g as c,f as u,b as f}from"./index-894ae36a.js";import{I as h}from"./ItemsListing-2b5a8c5f.js";import"./VCheckbox-4fd4d9b8.js";import"./eventbus-f225a5d6.js";import"./VListItem-4174a915.js";import"./VCheckboxBtn-24370bba.js";import"./VList-48dd7d0f.js";import"./VCardText-f53aa54e.js";import"./VCard-3391db98.js";import"./VMenu-6b993280.js";import"./_plugin-vue_export-helper-c27b6911.js";import"./ListItem-8a38a33e.js";import"./Button-f6514084.js";import"./VSpacer-46dc65f8.js";/* empty css              */import"./PanelviewItemCompact-b99e3c0c.js";import"./VAlert-a768baba.js";import"./Container-0e8820c0.js";import"./Toolbar-43508ce0.js";import"./VToolbar-92b7b4d6.js";import"./VTextField-d7aa64d7.js";import"./VInfiniteScroll-3988a0eb.js";import"./layout-ca8c09ab.js";import"./VVirtualScroll-3adad00e.js";const J=s({__name:"BrowseView",props:{path:{}},setup(i){const t=i,{t:r}=m(),a=n(()=>!t.path||t.path=="root"?r("browse"):e("bp6")?r("browse")+" | "+t.path:e("bp3")?t.path:r("browse")),p=async function(o){return await f.browse(o.offset,o.limit,t.path)};return(o,d)=>(l(),c("section",null,[u(h,{itemtype:"browse","show-provider":!1,"show-library":!1,"show-favorites-only-filter":!1,"show-track-number":!1,"load-paged-data":p,"sort-keys":["original","name","name_desc"],title:a.value,path:o.path,"allow-key-hooks":!0,icon:"mdi-folder-outline","no-server-side-sorting":!0},null,8,["title","path"])]))}});export{J as default};
